@@ -5,7 +5,7 @@ use warnings;
 
 package Validation::Class::Plugin::FormFields;
 {
-  $Validation::Class::Plugin::FormFields::VERSION = '0.0.5';
+  $Validation::Class::Plugin::FormFields::VERSION = '0.0.6';
 }
 
 use Moose::Role;
@@ -13,7 +13,7 @@ use File::ShareDir qw/dist_dir/;
 use Template;
 use Template::Stash;
 
-our $VERSION = '0.0.5'; # VERSION
+our $VERSION = '0.0.6'; # VERSION
 
 
 # field element templates
@@ -114,7 +114,7 @@ Validation::Class::Plugin::FormFields - Validation::Class HTML Form Field Render
 
 =head1 VERSION
 
-version 0.0.5
+version 0.0.6
 
 =head1 SYNOPSIS
 
@@ -158,25 +158,20 @@ version 0.0.5
 =head1 DESCRIPTION
 
 More importanly than explaining what this plugin is, I will first proclaim what
-it IS NOT. Validation::Class::Plugin::FormFields is not an HTML form and/or
-HTML element construction kit, nor is it a one-size-fits-all form handling machine,
-it is however a plugin for use with your L<Validation::Class> class that allows
-you to render HTML form fields based on your defined validation fields in
-their given states.
+it IS NOT. Validation::Class::Plugin::FormFields is not an HTML form construction
+kit, nor is it a one-size-fits-all form handling machine, ... it is however a
+plugin for use with your L<Validation::Class> class that allows you to render
+HTML form fields based on your defined validation fields.
 
-So why why render fields individually and not the entire form (fields collection).
-Form generation is pretty evil IMO, whereas the generating of HTML elements is
-less evil and definately alot more rational. Full-blown form generation locks
-you in a box offering only slight convenience and major headaches when you need
-anything more than the out-of-the-box generated output.
+Why render fields individually and not the entire form?
+Form generation is pretty evil (IMHO), whereas the generating of HTML elements
+is alot less evil and definately alot more rational. Full-blown form generation
+locks you in a box offering only slight convenience and major headaches when you
+need anything more than the out-of-the-box generated output.
 
-Render elements indivually, obviously we have to generate some output or this
-plugin would be a ridiculous waste of space, however .. the generated HTML is
-sensible and consistent to allow easy CSS styling and JavaScript manipulations.
-
-Ever tried to add an HTML5 <button>Click Me</button> or Horizontal Rule <hr/> to
-your form that was generated by that form rendering package you used to use ...?
-Don't render forms with code, Take back control of your controls.
+Obviously we have to generate some output or this plugin would be a ridiculous
+waste of space, that said however, the generated HTML is sensible and consistent
+and allows easy CSS styling and JavaScript manipulation.
 
 For more information about defining fields (validation rules), feel free to look
 over L<Validation::Class>. 
@@ -368,16 +363,17 @@ multi-line text input.
 
 =head1 HTML FORM FIELD TEMPLATES
 
-The HTML form field elements are rendered via TT template (template-toolkit).
+The HTML form field elements are rendered via TT (template-toolkit) templates.
 The actual template files are embedded in this distribution however you may copy
 them to your current working directory by issuing the following command at the
 command-line:
 
-    $ Validation-Class-Plugin-FormField-Templates [<path>]
+    $ Validation-Class-Plugin-FormField-Templates.pl [<path>]
 
-Once copied and modified to your liking, specify the CWD in your validation
-class instance as follows:
+Once copied and modified to your liking, specify the current working directory
+in your validation class instance as follows:
 
+    my $form = MyVal->new;
     $form->field_templates_location($location);
 
 =head1 AUTHOR
